@@ -6,6 +6,7 @@
  *  Copyright (c) 2001 Apple Computer, Inc. All rights reserved.
  *
  */
+ 
 #ifndef __TEXAS2_EQ_PREFS__
 #define __TEXAS2_EQ_PREFS__
  
@@ -16,7 +17,7 @@ EQPrefs         theEQPrefs =
 {
     0x00000001,                         // structVersionNumber
     0x72617720,                         // genreType = 'raw '
-    0x00000008,                         // eqCount
+    0x00000009,                         // eqCount	(update EQPrefsElement array size in AppleTexas2EQPrefs.cpp when updating eqCount!)
     0x00000000,                         // nameID
     {                                   // eq
         {                               // ----------     Equalization Set #1     ----------
@@ -135,7 +136,7 @@ EQPrefs         theEQPrefs =
                 {{{ 0x0F, 0xC6, 0x86 }, { 0xE2, 0x29, 0x47 }, { 0x0E, 0x4B, 0x5D }, { 0xE2, 0x29, 0x47 }, { 0x0E, 0x11, 0xE4 }}}
             }                           // end of filter set
 		},
-		{
+		{                               // ----------     Equalization Set #5     ----------
             /*  44100.0 */   44100,     // filterSampleRate
             /*     3.0  */       3,     // drcCompressionRatioNumerator
             /*     1.0  */       1,     // drcCompressionRatioDenominator
@@ -164,7 +165,7 @@ EQPrefs         theEQPrefs =
                 {{{ 0x10, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }}}
             }                           // end of filter set
 		},
-		{
+		{                               // ----------     Equalization Set #6     ----------
             /*  44100.0 */   44100,     // filterSampleRate
             /*     3.0  */       3,     // drcCompressionRatioNumerator
             /*     1.0  */       1,     // drcCompressionRatioDenominator
@@ -193,7 +194,7 @@ EQPrefs         theEQPrefs =
                 {{{ 0x10, 0x02, 0x82 }, { 0xE0, 0x6F, 0x60 }, { 0x0F, 0x92, 0xE8 }, { 0xE0, 0x6F, 0x60 }, { 0x0F, 0x95, 0x6B }}}
             }                           // end of filter set
 		},
-		{
+		{                               // ----------     Equalization Set #7     ----------
             /*  44100.0 */   44100,     // filterSampleRate
             /*     3.0  */       3,     // drcCompressionRatioNumerator
             /*     1.0  */       1,     // drcCompressionRatioDenominator
@@ -222,7 +223,7 @@ EQPrefs         theEQPrefs =
                 {{{ 0x10, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }}}
             }                           // end of filter set
 		},
-		{
+		{                               // ----------     Equalization Set #8     ----------
             /*  44100.0 */   44100,     // filterSampleRate
             /*     3.0  */       3,     // drcCompressionRatioNumerator
             /*     1.0  */       1,     // drcCompressionRatioDenominator
@@ -249,6 +250,35 @@ EQPrefs         theEQPrefs =
                 {{{ 0x10, 0xEB, 0x1C }, { 0xF7, 0x7C, 0x0E }, { 0x09, 0x05, 0xD9 }, { 0xF7, 0x7C, 0x0E }, { 0x09, 0xF0, 0xF5 }}},
                 {{{ 0x0E, 0xC8, 0xEA }, { 0xF9, 0xEE, 0xBB }, { 0x0D, 0x9A, 0x24 }, { 0xF9, 0xEE, 0xBB }, { 0x0C, 0x63, 0x0E }}},
                 {{{ 0x10, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }}}
+            }                           // end of filter set
+		},
+		{                               // ----------     Equalization Set #9     ----------
+            /*  44100.0 */   44100,     // filterSampleRate
+            /*     3.0  */       3,     // drcCompressionRatioNumerator
+            /*     1.0  */       1,     // drcCompressionRatioDenominator
+            /*    -9.0  */   -9000,     // drcThreshold     (X1000)
+            /*    -3.0  */      -6,     // drcMaximumVolume (X2)
+            0x00000001,                 // drcEnable    = ENABLED
+            0x0000001F,                 // layoutID     = (as appropriate)
+            0x00000001,                 // deviceID     = internal speaker
+            0x00000000,                 // speakerID    = (as appropriate)
+            0x00000000,                 // reserved     = 0 
+            0x0000000E,                 // filterCount  = 14
+            {                           // filter coefficients in sets of:  b0, b1, b2, a1, a2 and are in 4.20 format
+                {{{ 0x10, 0x0E, 0xFB }, { 0xE0, 0xB6, 0xFD }, { 0x0F, 0x3D, 0xCA }, { 0xE0, 0xB6, 0xFD }, { 0x0F, 0x4C, 0xC5 }}},
+                {{{ 0x0F, 0xC8, 0xF2 }, { 0xE1, 0x3B, 0x36 }, { 0x0F, 0x17, 0xA8 }, { 0xE1, 0x3B, 0x36 }, { 0x0E, 0xE0, 0x9A }}},
+                {{{ 0x0F, 0xD3, 0xA2 }, { 0xE2, 0x2D, 0x89 }, { 0x0E, 0xFE, 0x50 }, { 0xE2, 0x2D, 0x89 }, { 0x0E, 0xD1, 0xF2 }}},
+                {{{ 0x10, 0x84, 0x41 }, { 0x03, 0x48, 0xF3 }, { 0x0A, 0x0B, 0x20 }, { 0x03, 0x48, 0xF3 }, { 0x0A, 0x8F, 0x61 }}},
+                {{{ 0x10, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }}},
+                {{{ 0x10, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }}},
+                {{{ 0x10, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }}},
+                {{{ 0x10, 0x0E, 0xFB }, { 0xE0, 0xB6, 0xFD }, { 0x0F, 0x3D, 0xCA }, { 0xE0, 0xB6, 0xFD }, { 0x0F, 0x4C, 0xC5 }}},
+                {{{ 0x0F, 0xC8, 0xF2 }, { 0xE1, 0x3B, 0x36 }, { 0x0F, 0x17, 0xA8 }, { 0xE1, 0x3B, 0x36 }, { 0x0E, 0xE0, 0x9A }}},
+                {{{ 0x0F, 0xD3, 0xA2 }, { 0xE2, 0x2D, 0x89 }, { 0x0E, 0xFE, 0x50 }, { 0xE2, 0x2D, 0x89 }, { 0x0E, 0xD1, 0xF2 }}},
+                {{{ 0x10, 0x84, 0x41 }, { 0x03, 0x48, 0xF3 }, { 0x0A, 0x0B, 0x20 }, { 0x03, 0x48, 0xF3 }, { 0x0A, 0x8F, 0x61 }}},
+                {{{ 0x10, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }}},
+                {{{ 0x10, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }}},
+                {{{ 0x10, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }}},
             }                           // end of filter set
 		}
     }
